Example notebooks
=================

.. toctree::
    :maxdepth: 1

    Getting started with Hyrax <pre_executed/train_model>
    Getting started with Hyrax Custom Datasets <pre_executed/custom_dataset>
    Training to Similarity Search <pre_executed/hsc_train_to_similarity_search>
    Working with a vector database <pre_executed/vector_db_demo>
